<?php

namespace Inouit\InGalleryFlickr\Controller;

/**
 * The viewer controller for the in_gallery_flickr extension
 *
 * @package in_gallery_flickr
 *
 */
class ViewerController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {

	/**
	 * @var \Inouit\InGalleryFlickr\Domain\Repository\AlbumRepository
	 * @inject
	 */
	protected $albumRepository;

	/**
	 * @var \Inouit\InGalleryFlickr\Domain\Repository\ViewerRepository
	 * @inject
	 */
	protected $viewerRepository;

	/**
	 * Initialize view
	 *
	 * @return void
	 */
	public function initializeView(\TYPO3\CMS\Extbase\Mvc\View\ViewInterface $view) {
		$pageRenderer = $GLOBALS['TSFE']->getPageRenderer();
		if($this->settings['includeJQuery']) {
			$pageRenderer->addJsLibrary( 'jquery', '/typo3conf/ext/in_gallery_flickr/Resources/Public/Media/js/jquery-1.7.2.min.js' );
		}
		if($this->settings['includeFancyBox']) {
			$pageRenderer->addJsFooterLibrary( 'jquery.fancybox', '/typo3conf/ext/in_gallery_flickr/Resources/Public/Media/js/fancybox/jquery.fancybox-1.3.4.js' );
			$pageRenderer->addJsFooterLibrary( 'jquery.mousewheel', '/typo3conf/ext/in_gallery_flickr/Resources/Public/Media/js/fancybox/jquery.mousewheel-3.0.4.pack.js' );
			$pageRenderer->addJsFooterLibrary( 'jquery.easing', '/typo3conf/ext/in_gallery_flickr/Resources/Public/Media/js/fancybox/jquery.easing-1.3.pack.js' );

			$pageRenderer->addCssFile('/typo3conf/ext/in_gallery_flickr/Resources/Public/Media/js/fancybox/jquery.fancybox-1.3.4.css');
		}
		if($this->settings['includeGalleryCSS']) {
			$pageRenderer->addCssFile	('/typo3conf/ext/in_gallery_flickr/Resources/Public/Media/styles/inouit.gallery.viewer.css');
		}
		if($this->settings['includeGalleryJS']) {
			$pageRenderer->addJsFooterLibrary( 'in_gallery_flickr.hammer', '/typo3conf/ext/in_gallery_flickr/Resources/Public/Media/js/jquery.hammer.js' );
			$pageRenderer->addJsFooterLibrary( 'in_gallery_flickr.function', '/typo3conf/ext/in_gallery_flickr/Resources/Public/Media/js/function.js');
		}

		if($this->settings['album']['itemPerPage'] !== null && $this->settings['album']['itemPerPage'] > 0) {
			$pageRenderer->addCssFile('/typo3conf/ext/in_gallery_flickr/Resources/Public/Media/js/jquery.paginate/jquery.paginate.css');
			$pageRenderer->addJsFooterLibrary( 'jquery.paginate', '/typo3conf/ext/in_gallery_flickr/Resources/Public/Media/js/jquery.paginate/jquery.paginate.js' );
			$pageRenderer->addJsFooterInlineCode( 'jquery.paginateInit', '
				(function($){
					$(document).ready(function(){
						$(".albumList").paginate({ children: ".album", itemPerPage: "'.$this->settings['album']['itemPerPage'].'" });
					});
				})(jQuery);
			' );
		}


    	parent::initializeAction();
	}

	/**
	 * Show action for the Viewer
	 *
	 * @param Tx_InGalleryFlickr_Domain_Model_Album $album
	 * @return void
	 */
	public function showAction(\Inouit\InGalleryFlickr\Domain\Model\Album $album = null) {
		if($album === null){
			if($this->settings['album']['requestedAlbum'] != null){
				$album = $this->albumRepository->findByUid($this->settings['album']['requestedAlbum']);
			}else {
				$results = $this->albumRepository->findOneFirst();
				if($results !== null && count($results)) {
					$album = $results->current();
				}
			}
		}

		$photos = array();
		if($album !== null) {
			$photos = $this->viewerRepository->findByAlbum($album);
		}

        $this->view->assignMultiple(array(
        	'album' => $album,
        	'photos' => $photos
        	));
	}
}