<?php

namespace Inouit\InGalleryFlickr\Domain\Repository;

/**
 * A repository for album
 *
 * @package in_gallery_flickr
 *
 */
class ViewerRepository extends \TYPO3\CMS\Extbase\Persistence\Repository {
	/**
	 * Extension key
	 *
	 * @var string
	 */
	private $_EXTKEY = 'in_gallery_flickr';

	/**
	 * API key
	 *
	 * @var string
	 */
	private $apiKey = 'apiKey';

	/**
	 * An Instance of Inouit\InGalleryFlickr\Service\FlickrService
	 *
	 * @var \Inouit\InGalleryFlickr\Service\FlickrService
 	 * @inject
	 */
	protected $flickrService;

	/**
	 * @var \Inouit\InGalleryFlickr\Domain\Repository\AlbumRepository
	 * @inject
	 */
	protected $albumRepository;

  /**
   * @var \TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface
   * @inject
   */
  protected $configurationManager;

	/**
	 * find photos of the album
	 * @param  \Inouit\InGalleryFlickr\Domain\Model\Album $album
	 * @return ArrayCollection list of photos
	 */
	public function findByAlbum(\Inouit\InGalleryFlickr\Domain\Model\Album $album) {
		$this->flickrService->setApiKey($this->_EXTKEY);
		if($album) {
			$results = $this->flickrService->prepareAndSendRequest(array(
					'method'      	=> 'flickr.photosets.getPhotos',
					'photoset_id' 	=> $album->getAlbumId(),
					'extras'		=> 'original_format'
				));

			if($results['photoset'] && count($results['photoset']['photo'])) {
				return $this->getCollectionFromQueryResults($results['photoset']['photo']);
			}
		}

		return array();
	}

	public function getCollectionFromQueryResults(array $results = array()) {
		$collection = array();

		if(count($results)) {
			foreach ($results as $photoInfos) {
				$photo = new \Inouit\InGalleryFlickr\Domain\Model\Photo();
				$photo->__populate($photoInfos);
				array_push($collection, $photo);
			}
		}


    $configuration = $this->configurationManager->getConfiguration(\TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface::CONFIGURATION_TYPE_FRAMEWORK);
    $querySettings = $this->objectManager->get('TYPO3\CMS\Extbase\Persistence\Generic\Typo3QuerySettings');

    if($configuration['settings'] && $configuration['settings']['viewer'] && $configuration['settings']['viewer']['reverseCollection']){
			return array_reverse($collection);
    }else {
			return $collection;
    }
	}
}
?>