<?php

namespace Inouit\InGalleryFlickr\Service;

class FlickrService implements \TYPO3\CMS\Core\SingletonInterface {
	/**
	 * The base url for API requests.
	 *
	 * @var string
	 */
	const BASE_URL = 'https://api.flickr.com/services/rest/';

	/**
	 * API Key
	 * @var string
	 */
	protected $apiKey;

	/**
	 * Default params to a flickr call
	 * @var array
	 */
	protected $defaultParams = array(
		'format'      => 'php_serial'
		);

	/**
	 * Display errors
	 * @var array
	 */
	protected $displayErrors = false;

	/**
	 * find the apiKey in extension configuration
	 *
	 * @param string $extKey Extension key
	 * @return void
	 */
	public function setApiKey($extKey) {
		$extConf = unserialize($GLOBALS['TYPO3_CONF_VARS']['EXT']['extConf'][$extKey]);

		if($extConf['flickrApiKey'] !== null) {
			$this->apiKey = $this->apiKey = $extConf['flickrApiKey'];

	    	$this->defaultParams['oauth_consumer_key'] = $this->apiKey;
		}else {
			if($this->displayErrors) {
				throw new \TYPO3\CMS\Extbase\Mvc\Exception\InvalidArgumentValueException("You must set an API key", 1);
			}
		}

	}

	/**
	 * Getter for displayErrors
	 *
	 * @return string
	 */
	public function getDisplayErrors()
	{
	    return $this->displayErrors;
	}


	/**
	 * Setter for displayErrors
	 *
	 * @param  string  displayErrors
	 * @return string
	 */
	public function setDisplayErrors($displayErrors)
	{
	    $this->displayErrors = $displayErrors;
	    return $this;
	}


	/**
	 * Prepare and send request to Flickr's API
	 *
	 * @param  array  $params parameters of the request
	 * @return [type]         [description]
	 */
	public function prepareAndSendRequest(array $params=array()) {
		if( $this->apiKey !== null && $this->apiKey!='' ) {
			$callingParams = array_merge($this->defaultParams, $params);

			$url = $this->createURL($callingParams);
			$results = $this->sendRequest($url);

			return $this->parseResults($results);
		}else {
			if($this->displayErrors) {
				throw new \TYPO3\CMS\Extbase\Mvc\Exception\InvalidArgumentValueException("You must set an API key", 1);
			}
		}

		return array();
	}

	/**
	 * Create request's URL
	 *
	 * @param array $params Request parameters
	 * @return string
	 */
	protected function createURL(array $params = array()) {
		$fields_string = '';
		foreach ($params as $key => $value) {
			$fields_string .= $key . '=' . urlencode($value) . '&';
		}

		$fields_string = rtrim($fields_string, '&');
		$url = '?' . $fields_string;

		return self::BASE_URL . $url;
	}

	/**
	 * Send the request to flickr API
	 *
	 * @param  string $url Url of the request
	 * @return array 	$result of the request
	 */
	protected function sendRequest($url) {
		$curlHandle = curl_init();

		curl_setopt($curlHandle, CURLOPT_URL, $url);
		curl_setopt($curlHandle, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($curlHandle, CURLOPT_CONNECTTIMEOUT, 5);

		$results = unserialize(curl_exec($curlHandle));

		curl_close($curlHandle);

		return $results;
	}


	/**
	 * Parse the results to find data
	 *
	 * @param  array  $results
	 * @return array
	 */
	public function parseResults(array $results) {
		if($results['stat'] == 'fail'){
			if($this->displayErrors) {
				throw new \Exception('Error '.$results['code'].': '.$results['message'], 1);
			}
			return array();
		}else {
			return $results;
		}
	}

}