<?php

/*                                                                        *
 * This script is part of the TYPO3 project - inspiring people to share!  *
 *                                                                        *
 * TYPO3 is free software; you can redistribute it and/or modify it under *
 * the terms of the GNU General Public License version 2 as published by  *
 * the Free Software Foundation.                                          *
 *                                                                        *
 * This script is distributed in the hope that it will be useful, but     *
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHAN-    *
 * TABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General      *
 * Public License for more details.                                       *
 *                                                                        */
/**
 * A view helper for creating image tag form flickr.
 *
 * = Examples =
 *
 * <code title="image cover of an album">
 * <in:image.flickr provider="{album}" flickrSize="t"></in:image.flickr>
 * </code>
 * <output>
 * <img src="http://farm8.staticflickr.com/7306/9212665149_399f21c89b_t.jpg" alt="">
 * (depending on the album and your TS configuration)
 * </output>
 */

namespace Inouit\InGalleryFlickr\ViewHelpers\Image;

class FlickrViewHelper extends \TYPO3\CMS\Fluid\Core\ViewHelper\AbstractTagBasedViewHelper
{

    /**
     * @var string
     */
    protected $tagName = 'img';

    /**
    * Arguments initialization
    *
    * @return void
    */
    public function initializeArguments() {
        parent::initializeArguments();
        $this->registerUniversalTagAttributes();
        $this->registerTagAttribute('width', 'string', 'Width of the photo', false);
        $this->registerTagAttribute('height', 'string', 'Height of the photo', false);
    }

    /**
     * render
     *
     * @param mixed $provider Object to find the url of the image
     * @param string $flickrSize Size of the picture in flickr's speaking. Available size are : s, q, t, m, n, z, c, b (see Tx_InGalleryFlickr_Domain_Model_Album)
     * @param string urlOnly Get the URL instead of tag
     * @param string $alt Alternative of the photo
     * @throws \InvalidArgumentException
     * @throws \TYPO3\CMS\Extbase\Object\InvalidObjectException
     */


    public function render($provider, $flickrSize = "t", $urlOnly = false, $alt="") {
        if(!method_exists($provider, 'getPhotoUrl')){
            throw new \TYPO3\CMS\Extbase\Object\InvalidObjectException("This provider doesn't seem to have a \"getPhotoUrl\" method", 1);
        }

        if($urlOnly === true) {
            return $provider->getPhotoUrl($flickrSize);
        }
        $this->tag->addAttribute('src', $provider->getPhotoUrl($flickrSize));
        if ($alt && !empty($alt) && !is_array($alt)){
            $this->tag->addAttribute('alt', $alt);
        }else if ($alt && !empty($alt) && is_array($alt)){
            $this->tag->addAttribute('alt', $alt['photo']);
        }else{
            $this->tag->addAttribute('alt', '');
        }

        return $this->tag->render();
    }
}

?>