(function($){
$.fn.extend({
	paginate: function(options){
		var defaults = {
			itemPerPage : 10,
			children: '.item',
			pageItem: 'page-item',
			paginationItem: 'pagination-item',
			currentPage: 'current-page',
			refreshScroll: 0
		};
		var options = $.extend(defaults, options);

		return this.each(function(){
			var o = options;
			var $this = $(this);
			var $pages, $paginationContainer, $pagination ;
			var $children = $this.children(o.children);

			function isPaginationNeeded(){
				return ($children.length > o.itemPerPage);
			}

			function refreshSize(){
				$this.animate({ height: $pages.eq(getCurrentIndex()).height()}, 300);
			}

			function refreshScroll(){
				if(options.refreshScroll) { 
					$(window).scrollTop( $this.offset().top );
				}
			}

			function refreshArrow(){
				var current = getCurrentIndex();
				if(current == 0){
					$paginationContainer.children('.arrow-prev').hide();
				}else{
					$paginationContainer.children('.arrow-prev').show();
				}
				if(current == ($pagination.length-1)){
					$paginationContainer.children('.arrow-next').hide();
				}else{
					$paginationContainer.children('.arrow-next').show();
				}
			}

			function getCurrentIndex(){
				return $paginationContainer.children('.'+o.currentPage).index('.'+o.paginationItem);
			}

			function wrapPages() {
				for(var i=0; i < Math.ceil($children.length/o.itemPerPage); i++){
					$this.children(o.children+':lt('+o.itemPerPage+')').wrapAll(
						$('<div/>').addClass(o.pageItem)
							.addClass(o.pageItem+'-'+i)
					);
				}

				$pages = $this.children('.'+o.pageItem);
				$pages.not(':eq(0)').fadeOut(0);
			}

			function initPagination() {
				$paginationContainer = $('<p/>').addClass('pagination');
				var item = $('<a/>').attr('href','javascript:;');
				for(var i=0; i < Math.ceil($children.length/o.itemPerPage); i++){
					item.clone()
						.addClass(o.paginationItem)
						.html(i+1)
						.click(function(){ 
							gotoIndex($(this).index('.'+o.paginationItem));
							refreshScroll();
						})
						.appendTo($paginationContainer);
				}

				var prev = item.clone()
								.addClass('arrow')
								.addClass('arrow-prev')
								.html('&lt;')
								.click(function(){
									var index = getCurrentIndex();
									gotoIndex(index-1);	
									refreshScroll();
								})
								.prependTo($paginationContainer);

				var next = item.clone()
								.addClass('arrow')
								.addClass('arrow-next')
								.html('&gt;')
								.click(function(){
									var index = getCurrentIndex();
									gotoIndex(index+1);	
									refreshScroll();
								})
								.appendTo($paginationContainer);

				$this.after($paginationContainer);
				$pagination = $paginationContainer.children('.'+o.paginationItem);
			}

			function gotoIndex(index){
				hideAll();

				$pages.eq(index).fadeIn();
				$pagination.eq(index).addClass(o.currentPage);
				refreshSize();
				refreshArrow();
			}

			function hideAll() {
				$pages.fadeOut();
				$pagination.removeClass(o.currentPage);
			}

			if(isPaginationNeeded()) {
				$this.addClass('paginatedList');
				wrapPages();
				initPagination();

				gotoIndex(0);
			}
		});
	}
});
})(jQuery);